@@ -3,6 +3,8 @@ API client for ivybloom CLI
 """
 
 import httpx
+import time
+import uuid
 import sys
 import json
 from typing import Dict, Any, Optional, List
@@ -46,7 +48,7 @@ class IvyBloomAPIClient:
         # Build default headers including auth; prefer API key for stability, then JWT/OAuth
         headers = {
             "Content-Type": "application/json",
-            "User-Agent": "ivybloom-cli/0.5.15",
+            "User-Agent": "ivybloom-cli/0.6.2",
             "Accept": "application/json"
         }
         # Add Authorization header via AuthManager (JWT/OAuth/API key)
@@ -73,21 +75,51 @@ class IvyBloomAPIClient:
         try:
             # Ensure endpoint joins correctly with base_url
             path = endpoint if endpoint.startswith("/") else f"/{endpoint}"
-            
+
             # Ensure headers are fresh for this request
             self._refresh_headers()
-            
-            if self.config.get('debug'):
-                # Send debug logs to stderr to avoid contaminating stdout (which may be parsed as JSON)
-                print(f"{method} {endpoint} -> (sending request)", file=sys.stderr)
-            
-            response = self.client.request(method, path, **kwargs)
-            
-            if self.config.get('debug'):
-                # Route debug logs to stderr
-                print(f"{method} {endpoint} -> {response.status_code}", file=sys.stderr)
-            
-            return response
+
+            # Attach a per-request trace id header for observability (use fixed if provided)
+            configured_trace_id = self.config.get('trace_id')
+            trace_id = str(configured_trace_id) if configured_trace_id else str(uuid.uuid4())
+            headers_override = kwargs.pop("headers", None) or {}
+            headers_override.setdefault("x-trace-id", trace_id)
+
+            # Rate limit retry config
+            max_rl_retries = int(self.config.get('rate_limit_retries', 2) or 0)
+            backoff_base = float(self.config.get('rate_limit_backoff_base', 1.0) or 1.0)
+
+            attempt = 0
+            start_time = time.time()
+            while True:
+                if self.config.get('debug'):
+                    print(f"{method} {endpoint} [trace_id={trace_id}] -> (sending request)", file=sys.stderr)
+
+                response = self.client.request(method, path, headers=headers_override, **kwargs)
+
+                if response.status_code != 429:
+                    if self.config.get('debug'):
+                        duration_ms = int((time.time() - start_time) * 1000)
+                        print(f"{method} {endpoint} [trace_id={trace_id}] -> {response.status_code} ({duration_ms} ms)", file=sys.stderr)
+                    return response
+
+                # Handle 429 with basic backoff
+                if attempt >= max_rl_retries:
+                    if self.config.get('debug'):
+                        print(f"{method} {endpoint} [trace_id={trace_id}] -> 429 (giving up after {attempt} retries)", file=sys.stderr)
+                    return response
+
+                retry_after_header = response.headers.get('Retry-After') or response.headers.get('retry-after')
+                sleep_seconds: float
+                try:
+                    sleep_seconds = float(retry_after_header) if retry_after_header else backoff_base * (2 ** attempt)
+                except Exception:
+                    sleep_seconds = backoff_base * (2 ** attempt)
+                sleep_seconds = max(0.1, min(sleep_seconds, 10.0))
+                if self.config.get('debug'):
+                    print(f"{method} {endpoint} [trace_id={trace_id}] -> 429 (retrying in {sleep_seconds:.2f}s)", file=sys.stderr)
+                time.sleep(sleep_seconds)
+                attempt += 1
         except httpx.TimeoutException:
             raise Exception("Request timed out. Check your network and try again.")
         except httpx.ConnectError:
@@ -520,7 +552,183 @@ class IvyBloomAPIClient:
     def update_config_settings(self, settings: Dict[str, Any]) -> Dict[str, Any]:
         """Update CLI configuration settings"""
         return self.post("/api/cli/config", json_data=settings)
+
+    # ---------------------------
+    # Reports/Exports (frontend)
+    # ---------------------------
+    def reports_post(
+        self,
+        action: str,
+        *,
+        job_id: str,
+        template: Optional[str] = None,
+        export_type: Optional[str] = None,
+        format: Optional[str] = None,
+        extra_params: Optional[Dict[str, Any]] = None,
+        idempotency_key: Optional[str] = None,
+    ) -> Dict[str, Any]:
+        """POST /api/cli/reports to trigger async readiness/self-heal flows.
+
+        Semantics per frontend:
+          - action=preview|generate|export
+          - POST returns 202 for async trigger (no long-running body)
+        """
+        self._ensure_authenticated()
+
+        # Build query string parameters
+        params: Dict[str, Any] = {"action": action, "jobId": job_id}
+        if template:
+            params["template"] = template
+        if export_type:
+            params["type"] = export_type
+        if format:
+            params["format"] = format
+        if extra_params:
+            params.update(extra_params)
+        # Opportunistically include idempotency key as query param for backends that accept it in URL
+        if idempotency_key:
+            # Use both snake_case and camelCase for broader compatibility
+            params.setdefault("idempotency_key", idempotency_key)
+            params.setdefault("idempotencyKey", idempotency_key)
+
+        # Use POST with query params; no body needed
+        path = "/api/cli/reports"
+        # Provide Idempotency-Key headers for servers that accept header-based keys
+        request_headers: Dict[str, str] | None = None
+        if idempotency_key:
+            request_headers = {
+                "Idempotency-Key": idempotency_key,
+                "x-idempotency-key": idempotency_key,
+            }
+        response = self._make_request("POST", path, params=params, headers=request_headers)
+
+        # 202 Accepted is expected; return parsed JSON if present
+        try:
+            return response.json()
+        except json.JSONDecodeError:
+            return {"status_code": response.status_code}
+
+    def reports_get(
+        self,
+        action: str,
+        *,
+        job_id: str,
+        template: Optional[str] = None,
+        export_type: Optional[str] = None,
+        format: Optional[str] = None,
+        follow_redirects: bool = True,
+        extra_params: Optional[Dict[str, Any]] = None,
+    ) -> Dict[str, Any]:
+        """GET /api/cli/reports to fetch preview/generate content or export redirect.
+
+        When follow_redirects=False and the server responds with 302, the Location
+        header is returned under {'redirect_to': url} for the caller to handle.
+        """
+        self._ensure_authenticated()
+
+        params: Dict[str, Any] = {"action": action, "jobId": job_id}
+        if template:
+            params["template"] = template
+        if export_type:
+            params["type"] = export_type
+        if format:
+            params["format"] = format
+        if extra_params:
+            params.update(extra_params)
+
+        # Optimize: use built-in client if following redirects; otherwise spin a local client
+        path = "/api/cli/reports"
+        if follow_redirects:
+            response = self._make_request("GET", path, params=params)
+            try:
+                return response.json()
+            except json.JSONDecodeError:
+                # Return textual content when not JSON (e.g., HTML or raw)
+                return {"data": response.text, "status_code": response.status_code}
+
+        # No-follow mode to capture redirect target
+        try:
+            # Build a temporary client honoring current headers
+            temp_client = httpx.Client(
+                base_url=self.base_url,
+                timeout=self.timeout,
+                headers=self._get_default_headers(),
+                follow_redirects=False,
+            )
+            response = temp_client.request("GET", path, params=params)
+        finally:
+            try:
+                temp_client.close()
+            except Exception:
+                pass
+
+        if response.status_code in (301, 302, 303, 307, 308):
+            return {
+                "status_code": response.status_code,
+                "redirect_to": response.headers.get("location", "")
+            }
+        try:
+            return response.json()
+        except json.JSONDecodeError:
+            return {"data": response.text, "status_code": response.status_code}
     
+    # ---------------------------
+    # Exports Orchestrator (optional surface)
+    # ---------------------------
+    def create_export(
+        self,
+        spec: Dict[str, Any],
+        *,
+        idempotency_key: Optional[str] = None,
+    ) -> Dict[str, Any]:
+        """POST /api/cli/exports to create an export orchestration.
+
+        Sends idempotency keys via headers and includes in payload for
+        compatibility across deployments.
+        """
+        self._ensure_authenticated()
+        headers: Dict[str, str] | None = None
+        if idempotency_key:
+            headers = {
+                "Idempotency-Key": idempotency_key,
+                "x-idempotency-key": idempotency_key,
+            }
+            # Also include in request body to ease backend ingestion
+            spec = dict(spec)
+            spec.setdefault("idempotency_key", idempotency_key)
+        response = self._make_request("POST", "/api/cli/exports", json=spec, headers=headers)
+        try:
+            return response.json()
+        except json.JSONDecodeError:
+            return {"status_code": response.status_code}
+
+    def get_export_status(self, export_id: str) -> Dict[str, Any]:
+        """GET /api/cli/exports/{id} for export status."""
+        self._ensure_authenticated()
+        response = self._make_request("GET", f"/api/cli/exports/{export_id}")
+        try:
+            return response.json()
+        except json.JSONDecodeError:
+            return {"status_code": response.status_code, "data": response.text}
+
+    def get_export_results(self, export_id: str) -> Dict[str, Any]:
+        """GET /api/cli/exports/{id}/results for completed manifest and URLs."""
+        self._ensure_authenticated()
+        response = self._make_request("GET", f"/api/cli/exports/{export_id}/results")
+        try:
+            return response.json()
+        except json.JSONDecodeError:
+            return {"status_code": response.status_code, "data": response.text}
+
+    def list_export_catalog(self) -> Dict[str, Any]:
+        """GET /api/cli/exports/catalog for export types and allowed items."""
+        self._ensure_authenticated()
+        response = self._make_request("GET", "/api/cli/exports/catalog")
+        try:
+            return response.json()
+        except json.JSONDecodeError:
+            return {"status_code": response.status_code, "data": response.text}
+
     def close(self):
         """Close the HTTP client"""
         self.client.close()
