@@ -696,9 +696,21 @@ def _wait_for_cli_linking(config: Config, auth_manager: AuthManager, client_id:
                                         progress.update(task, description="✅ API key retrieved and stored!")
                                         time.sleep(0.5)
                                     
-                                    # Note: Frontend handles all Clerk authentication
-                                    # CLI only needs the API key to authenticate with frontend
+                                    # If the frontend provides a Clerk session/JWT for CLI, store it as well
+                                    try:
+                                        clerk_session = verify_result.get('clerk_session')
+                                        if isinstance(clerk_session, dict):
+                                            # Store long-lived JWT if present
+                                            jwt_token = clerk_session.get('jwt') or clerk_session.get('token')
+                                            if isinstance(jwt_token, str) and jwt_token.strip():
+                                                auth_manager.store_auth_token(jwt_token.strip())
+                                            # Persist full Clerk session for potential future use/validation
+                                            auth_manager.store_clerk_session(clerk_session)
+                                    except Exception:
+                                        # Non-fatal; proceed with API key auth only
+                                        pass
                                     
+                                    # Ready to proceed
                                     return True
                                 else:
                                     progress.update(task, description="❌ Verification failed!")
