@@ -16,6 +16,7 @@ from ..client.api_client import IvyBloomAPIClient
 from ..utils.config import Config
 from ..utils.auth import AuthManager
 from ..utils.colors import get_console, print_success, print_error, print_warning, print_info
+from ..utils.printing import emit_json
 
 console = get_console()
 
@@ -424,7 +425,7 @@ def results(ctx, job_ids: tuple, format: str, output_dir: str):
                 for result in results:
                     console.print(f"\n[bold]Job {result['job_id']}:[/bold]")
                     if format == 'json':
-                        console.print(json.dumps(result['result'], indent=2))
+                        emit_json(result['result'])
                     elif format == 'yaml':
                         console.print(yaml.dump(result['result'], default_flow_style=False))
                     else:
