@@ -68,6 +68,47 @@ def config():
     pass
 
 @config.command()
+@click.pass_context
+def validate(ctx):
+    """Validate configuration, connectivity, and optional dependencies.
+    
+    Checks:
+      • Frontend URL resolves and CLI endpoints respond
+      • API connectivity (account endpoint)
+      • Optional tools: FlatProt (uvx/flatprot), DSSP (mkdssp)
+    """
+    import httpx
+    import shutil
+    config_obj = ctx.obj['config']
+    table = Table(title="🔧 Configuration Validation")
+    table.add_column("Check", style="cyan")
+    table.add_column("Result", style="green")
+    table.add_column("Details", style="yellow")
+    # Frontend
+    fe = config_obj.get_frontend_url()
+    try:
+        with httpx.Client(follow_redirects=True, timeout=10.0) as client:
+            r = client.get(f"{fe.rstrip('/')}/api/cli/link-status/test")
+        table.add_row("Frontend URL", "OK", f"{fe} ({r.status_code})")
+    except Exception as e:
+        table.add_row("Frontend URL", "FAIL", str(e))
+    # Account (auth)
+    try:
+        from ..utils.auth import AuthManager
+        from ..client.api_client import IvyBloomAPIClient
+        am = AuthManager(config_obj)
+        with IvyBloomAPIClient(config_obj, am) as client:
+            info = client.get_account_info()
+        table.add_row("Account endpoint", "OK", info.get('email', 'Unknown'))
+    except Exception as e:
+        table.add_row("Account endpoint", "FAIL", str(e))
+    # Optional deps
+    flatprot = bool(shutil.which("uvx") or shutil.which("flatprot"))
+    table.add_row("FlatProt available", "Yes" if flatprot else "No", "uvx flatprot or flatprot on PATH")
+    dssp = bool(shutil.which("mkdssp"))
+    table.add_row("DSSP (mkdssp)", "Yes" if dssp else "No", "Required for PDB inputs (FlatProt)")
+    console.print(table)
+
 @click.argument('key')
 @click.argument('value')
 @click.option('--type', type=click.Choice(['string', 'int', 'float', 'bool', 'json']), help='Value type (auto-detected if not specified)')
@@ -114,15 +155,59 @@ def set(ctx, key, value, type):
     💡 TIP: Complex JSON values should be quoted and use --type json
     """
     config_obj = ctx.obj['config']
-    
-    # Try to parse value as JSON for complex types
+
+    # Whitelist only safe, user-facing keys
+    allowed_top = {"debug", "visualization"}
+    if key not in allowed_top:
+        raise click.ClickException(
+            "Setting this configuration key is restricted. Allowed keys: 'debug', 'visualization'."
+        )
+
+    # Parse provided value (may be JSON)
     try:
         parsed_value = json.loads(value)
     except json.JSONDecodeError:
         parsed_value = value
-    
-    config_obj.set(key, parsed_value)
-    console.print(f"[green]✅ Set {key} = {parsed_value}[/green]")
+
+    if key == "debug":
+        # Coerce to boolean
+        val_str = str(parsed_value).strip().lower()
+        if isinstance(parsed_value, bool):
+            debug_val = parsed_value
+        elif val_str in {"true", "1", "yes", "y"}:
+            debug_val = True
+        elif val_str in {"false", "0", "no", "n"}:
+            debug_val = False
+        else:
+            raise click.ClickException("Invalid value for debug. Use true/false.")
+        config_obj.set("debug", debug_val)
+        console.print(f"[green]✅ Set debug = {debug_val}[/green]")
+        return
+
+    if key == "visualization":
+        # Only allow specific subkeys
+        if not isinstance(parsed_value, dict):
+            raise click.ClickException("Visualization value must be a JSON object with allowed keys.")
+        allowed_sub = {"prefer_flatprot", "flatprot_output_format", "flatprot_auto_open"}
+        disallowed = [k for k in parsed_value.keys() if k not in allowed_sub]
+        if disallowed:
+            raise click.ClickException(
+                f"Disallowed visualization keys: {', '.join(disallowed)}. Allowed: {', '.join(sorted(allowed_sub))}."
+            )
+        current = config_obj.get("visualization") or {}
+        if not isinstance(current, dict):
+            current = {}
+        merged = dict(current)
+        merged.update(parsed_value)
+        # Normalize format
+        if "flatprot_output_format" in merged:
+            fmt = str(merged["flatprot_output_format"]).lower()
+            if fmt not in {"svg", "png"}:
+                fmt = "svg"
+            merged["flatprot_output_format"] = fmt
+        config_obj.set("visualization", merged)
+        console.print(f"[green]✅ Updated visualization = {json.dumps(merged)}[/green]")
+        return
 
 @config.command()
 @click.argument('key')
