@@ -7,7 +7,7 @@ import time
 import json
 import requests
 from typing import Optional, Dict, Any
-from rich.console import Console
+from rich.console import Console, Group
 from rich.table import Table
 try:
     import humanize as _humanize
@@ -35,7 +35,7 @@ def jobs():
       - Results: ivybloom jobs results <job_id>
       - Download:ivybloom jobs download <job_id>
 
-    Tip: Use '--follow' to watch long-running jobs live.
+    Tip: Omit <job_id> on subcommands to pick a job interactively.
     """
     pass
 
@@ -221,22 +221,97 @@ def list(ctx, project_id, status, tool, limit, offset, created_after, created_be
     except Exception as e:
         console.print(f"[red]❌ Error listing jobs: {e}[/red]")
 
+def _resolve_job_id(ctx, job_id: Optional[str]) -> Optional[str]:
+    """Resolve a job identifier.
+
+    Behaviors:
+    - If job_id is None: open an interactive selector of recent jobs and return the selected id.
+    - If job_id is provided: accept as-is if retrievable; otherwise treat as a prefix and try to resolve uniquely.
+    """
+    from ..utils.interactive import select_from_list
+
+    config = ctx.obj['config']
+    auth_manager = AuthManager(config)
+    try:
+        with IvyBloomAPIClient(config, auth_manager) as client:
+            # No input: interactive select from recent jobs
+            if not job_id:
+                jobs_data = client.list_jobs(limit=50, offset=0)
+                if not jobs_data:
+                    console.print("[yellow]No jobs found to select.[/yellow]")
+                    return None
+                items = []
+                for job in jobs_data:
+                    jid = job.get('job_id') or job.get('id', '')
+                    jtype = job.get('tool_name') or job.get('job_type', '')
+                    title = job.get('job_title', 'Untitled')
+                    status = job.get('status', 'Unknown')
+                    items.append({
+                        'id': jid,
+                        'name': f"{jtype} - {title}",
+                        'description': f"{status} • {str(jid)[:8]}..."
+                    })
+                selected = select_from_list(items=items, title="Select a Job", display_key='name', id_key='id', description_key='description')
+                return selected
+
+            # Try direct fetch first (handles full IDs)
+            try:
+                data = client.get_job_status(job_id)
+                resolved = data.get('job_id') or data.get('id')
+                if resolved:
+                    return str(resolved)
+            except Exception:
+                pass
+
+            # Resolve as prefix among recent jobs
+            jobs_data = client.list_jobs(limit=100, offset=0)
+            matches = []
+            for job in jobs_data:
+                jid = str(job.get('job_id') or job.get('id') or '')
+                if jid.startswith(str(job_id)):
+                    matches.append(job)
+            if not matches:
+                console.print(f"[red]No job found matching prefix '{job_id}'.[/red]")
+                return None
+            if len(matches) == 1:
+                return str(matches[0].get('job_id') or matches[0].get('id'))
+            # Multiple matches: ask user to choose
+            items = []
+            for job in matches:
+                jid = job.get('job_id') or job.get('id', '')
+                jtype = job.get('tool_name') or job.get('job_type', '')
+                title = job.get('job_title', 'Untitled')
+                status = job.get('status', 'Unknown')
+                items.append({
+                    'id': jid,
+                    'name': f"{jtype} - {title}",
+                    'description': f"{status} • {str(jid)[:8]}..."
+                })
+            console.print(f"[yellow]Multiple jobs match prefix '{job_id}'. Please select:[/yellow]")
+            selected = select_from_list(items=items, title="Select a Job", display_key='name', id_key='id', description_key='description')
+            return selected
+    except Exception as e:
+        console.print(f"[red]❌ Error resolving job: {e}[/red]")
+        return None
+
+
 @jobs.command()
-@click.argument('job_id')
-@click.option('--follow', '-f', is_flag=True, help='Follow job progress')
+@click.argument('job_id', required=False)
+@click.option('--follow', '-f', is_flag=True, help='Follow job progress (periodic polling)')
 @click.option('--interval', default=5, show_default=True, type=int, help='Polling interval in seconds for --follow')
 @click.option('--logs', is_flag=True, help='Include execution logs')
 @click.option('--logs-tail', type=int, default=50, show_default=True, help='When --logs is set, include only the last N log lines')
 @click.option('--format', default='table', type=click.Choice(['table', 'json']), help='Output format')
+@click.option('--stream', is_flag=True, help='Deprecated alias for --follow')
 @click.pass_context
-def status(ctx, job_id, follow, interval, logs, logs_tail, format):
+def status(ctx, job_id, follow, interval, logs, logs_tail, format, stream):
     """📊 Monitor job status and progress
     
     Check the current status, progress, and details of a specific job.
     
     USAGE:
-      ivybloom jobs status <job_id>                # One-time status check
-      ivybloom jobs status <job_id> --follow      # Live progress monitoring
+      ivybloom jobs status [<job_id>]             # One-time status check (omit to select)
+      ivybloom jobs status <job_id> --follow      # Periodic polling updates
       ivybloom jobs status <job_id> --logs        # Include execution logs
       ivybloom jobs status <job_id> --format json # JSON output
     
@@ -254,7 +329,7 @@ def status(ctx, job_id, follow, interval, logs, logs_tail, format):
       🔴 FAILED      → Job encountered an error
       ⚫ CANCELLED   → Job was cancelled by user
     
-    💡 TIP: Use --follow to watch long-running jobs without manual refresh!
+    💡 TIP: Omit the job id to select from recent jobs. Use --follow only if you want periodic updates.
     """
     config = ctx.obj['config']
     auth_manager = AuthManager(config)
@@ -264,12 +339,15 @@ def status(ctx, job_id, follow, interval, logs, logs_tail, format):
         return
     
     try:
+        resolved_id = _resolve_job_id(ctx, job_id)
+        if not resolved_id:
+            return
         with IvyBloomAPIClient(config, auth_manager) as client:
-            if follow:
+            if follow or stream:
                 # Follow mode - continuously update status
                 with Live(console=console, refresh_per_second=2) as live:
                     while True:
-                        job_data = client.get_job_status(job_id, include_logs=logs, logs_tail=logs_tail if logs else None)
+                        job_data = client.get_job_status(resolved_id, include_logs=logs, logs_tail=logs_tail if logs else None)
                         
                         # Create status display
                         status_panel = _create_status_panel(job_data)
@@ -283,7 +361,7 @@ def status(ctx, job_id, follow, interval, logs, logs_tail, format):
                         time.sleep(max(1, int(interval)))  # Adjustable polling interval
             else:
                 # Single status check
-                job_data = client.get_job_status(job_id, include_logs=logs, logs_tail=logs_tail if logs else None)
+                job_data = client.get_job_status(resolved_id, include_logs=logs, logs_tail=logs_tail if logs else None)
                 
                 if format == 'json':
                     emit_json(job_data)
@@ -295,8 +373,8 @@ def status(ctx, job_id, follow, interval, logs, logs_tail, format):
         console.print(f"[red]❌ Error getting job status: {e}[/red]")
 
 @jobs.command()
-@click.argument('job_id')
-@click.option('--format', default='json', type=click.Choice(['json', 'yaml', 'csv']), help='Output format')
+@click.argument('job_id', required=False)
+@click.option('--format', default='json', type=click.Choice(['json', 'yaml', 'csv', 'table']), help='Output format')
 @click.option('--output', '-o', help='Save to file')
 @click.pass_context
 def results(ctx, job_id, format, output):
@@ -337,8 +415,11 @@ def results(ctx, job_id, format, output):
         return
     
     try:
+        resolved_id = _resolve_job_id(ctx, job_id)
+        if not resolved_id:
+            return
         with IvyBloomAPIClient(config, auth_manager) as client:
-            results_data = client.get_job_results(job_id, format=format)
+            results_data = client.get_job_results(resolved_id, format=format)
         
         if output:
             # Save to file
@@ -352,19 +433,22 @@ def results(ctx, job_id, format, output):
             # Print to console
             if format == 'json':
                 emit_json(results_data)
+            elif format == 'table':
+                renderable = _create_results_renderable(results_data)
+                console.print(renderable)
             else:
                 console.print(results_data)
         
         # Suggest download command only when not printing JSON to stdout
         if format != 'json' and not output:
             console.print(f"\n[dim]💡 To download result files (PDB, ZIP, etc.), use:[/dim]")
-            console.print(f"[dim]   ivybloom jobs download {job_id}[/dim]")
+            console.print(f"[dim]   ivybloom jobs download {resolved_id}[/dim]")
     
     except Exception as e:
         console.print(f"[red]❌ Error getting job results: {e}[/red]")
 
 @jobs.command()
-@click.argument('job_id')
+@click.argument('job_id', required=False)
 @click.option('--artifact-type', help='Specific artifact type to download (pdb, zip, csv, txt, sdf)')
 @click.option('--output-dir', '-d', help='Directory to save downloaded files', default='.')
 @click.option('--list-only', is_flag=True, help='List available artifacts without downloading')
@@ -408,8 +492,11 @@ def download(ctx, job_id, artifact_type, output_dir, list_only, format):
         return
     
     try:
+        resolved_id = _resolve_job_id(ctx, job_id)
+        if not resolved_id:
+            return
         with IvyBloomAPIClient(config, auth_manager) as client:
-            download_data = client.get_job_download_urls(job_id, artifact_type)
+            download_data = client.get_job_download_urls(resolved_id, artifact_type)
         
         if list_only:
             # Just show available artifacts
@@ -418,7 +505,7 @@ def download(ctx, job_id, artifact_type, output_dir, list_only, format):
                 return
             
             # Table format
-            console.print(f"[bold cyan]📥 Available Artifacts for Job {job_id[:8]}...[/bold cyan]")
+            console.print(f"[bold cyan]📥 Available Artifacts for Job {resolved_id[:8]}...[/bold cyan]")
             console.print(f"[cyan]Job Status:[/cyan] {download_data.get('job_status')}")
             console.print(f"[cyan]Job Type:[/cyan] {download_data.get('job_type')}")
             console.print(f"[cyan]Total Artifacts:[/cyan] {download_data.get('total_artifacts', 0)}")
@@ -554,12 +641,12 @@ def _execute_job_action(ctx, job_id: str, action: str, job_data: Dict[str, Any])
     
     try:
         if action == 'status':
-            # Show job status
-            status(ctx, job_id, False, False, 'table')
+            # Show job status (single check)
+            status(ctx, job_id, False, 5, False, 50, 'table', False)
             
         elif action == 'follow':
             # Monitor job live
-            status(ctx, job_id, True, False, 'table')
+            status(ctx, job_id, True, 5, False, 50, 'table', False)
             
         elif action == 'results':
             # Show job results
@@ -580,7 +667,7 @@ def _execute_job_action(ctx, job_id: str, action: str, job_data: Dict[str, Any])
         console.print(f"[red]❌ Error executing action '{action}': {e}[/red]")
 
 @jobs.command()
-@click.argument('job_id')
+@click.argument('job_id', required=False)
 @click.pass_context
 def cancel(ctx, job_id):
     """Cancel a running job"""
@@ -591,15 +678,18 @@ def cancel(ctx, job_id):
         console.print("[red]❌ Not authenticated. Run 'ivybloom auth login' first.[/red]")
         return
     
-    if not click.confirm(f"Are you sure you want to cancel job {job_id}?"):
+    resolved_id = _resolve_job_id(ctx, job_id)
+    if not resolved_id:
+        return
+    if not click.confirm(f"Are you sure you want to cancel job {resolved_id}?"):
         console.print("Cancelled.")
         return
     
     try:
         with IvyBloomAPIClient(config, auth_manager) as client:
-            result = client.cancel_job(job_id)
+            result = client.cancel_job(resolved_id)
         
-        console.print(f"[green]✅ Job {job_id} cancelled successfully[/green]")
+        console.print(f"[green]✅ Job {resolved_id} cancelled successfully[/green]")
     
     except Exception as e:
         console.print(f"[red]❌ Error cancelling job: {e}[/red]")
@@ -678,4 +768,79 @@ def _create_status_panel(job_data: dict) -> Panel:
         content,
         title="📊 Job Status",
         border_style=border_color
-    )
\ No newline at end of file
+    )
+
+def _create_results_renderable(results: dict) -> Panel | Group:
+    """Create a rich renderable for job results akin to status panel.
+
+    Expects a structure similar to:
+    {
+      "job_id": "...",
+      "tool_name": "esmfold",
+      "status": "success"|"failed"|...,  # normalized lower or upper
+      "results": { ... },
+      "output_files": [ { filename, download_url }, ... ]
+    }
+    """
+    job_id = results.get('job_id') or results.get('id', 'Unknown')
+    tool_name = results.get('tool_name') or results.get('job_type', 'Unknown')
+    status = (results.get('status') or '').upper()
+    outputs = results.get('results') or results.get('outputs') or {}
+    files = results.get('output_files') or results.get('artifacts') or []
+
+    status_styles = {
+        'SUCCESS': '[green]SUCCESS ✅[/green]',
+        'COMPLETED': '[green]COMPLETED ✅[/green]',
+        'FAILURE': '[red]FAILED ❌[/red]',
+        'FAILED': '[red]FAILED ❌[/red]'
+    }
+    styled_status = status_styles.get(status, results.get('status', 'unknown'))
+
+    # Summary panel
+    summary_lines = [
+        f"[bold cyan]Job ID:[/bold cyan] {job_id}",
+        f"[bold cyan]Tool:[/bold cyan] {tool_name}",
+        f"[bold cyan]Status:[/bold cyan] {styled_status}",
+    ]
+    # Add a few key output metrics if present (flat key-value pairs)
+    if isinstance(outputs, dict):
+        # Pick up to 6 simple fields to display
+        simple_items = []
+        for k, v in outputs.items():
+            if isinstance(v, (str, int, float, bool)) and len(simple_items) < 6:
+                simple_items.append((k, v))
+        for k, v in simple_items:
+            summary_lines.append(f"[bold cyan]{k.replace('_',' ').title():}[/bold cyan] {v}")
+
+    summary_panel = Panel("\n".join(summary_lines), title="📁 Job Results", border_style="green" if status in ["SUCCESS", "COMPLETED"] else "red" if status in ["FAILED", "FAILURE"] else "blue")
+
+    # Output files table (if present)
+    renderables: list = [summary_panel]
+    if files and isinstance(files, list):
+        table = Table(title="Output Files")
+        table.add_column("Filename", style="green")
+        table.add_column("Download", style="blue")
+        for fobj in files:
+            filename = str(fobj.get('filename') or fobj.get('name') or 'unknown')
+            download = str(fobj.get('download_url') or fobj.get('url') or '')
+            table.add_row(filename, download)
+        renderables.append(table)
+
+    # If outputs is a non-trivial dict, show a key-value table preview
+    if isinstance(outputs, dict) and outputs:
+        kv = Table(title="Result Summary (subset)")
+        kv.add_column("Field", style="cyan")
+        kv.add_column("Value", style="yellow")
+        shown = 0
+        for k, v in outputs.items():
+            if isinstance(v, (str, int, float, bool)):
+                kv.add_row(str(k), str(v))
+                shown += 1
+                if shown >= 10:
+                    break
+        if shown:
+            renderables.append(kv)
+
+    if len(renderables) == 1:
+        return summary_panel
+    return Group(*renderables)
\ No newline at end of file
