@@ -186,7 +186,7 @@ def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_s
             
             console.print()
             console.print("[dim]📋 Next steps:[/dim]")
-            console.print(f"   [dim]• Monitor: ivybloom jobs status {job_id}[/dim]")
+            console.print(f"   [dim]• Monitor: ivybloom jobs status {job_id} --stream[/dim]")
             console.print(f"   [dim]• Results: ivybloom jobs results {job_id}[/dim]")
             console.print(f"   [dim]• Download: ivybloom jobs download {job_id}[/dim]")
             
@@ -599,7 +599,7 @@ def _wait_for_completion(client, job_id):
                 progress.update(task, description="Cancelled by user!")
                 time.sleep(0.5)
                 console.print("\n[yellow]Stopped waiting, but job continues running on server.[/yellow]")
-                console.print(f"[dim]Check status: ivybloom jobs status {job_id}[/dim]")
+                console.print(f"[dim]Check status: ivybloom jobs status {job_id} --stream[/dim]")
                 return
             except Exception as e:
                 progress.update(task, description=f"Error: {e}")
@@ -614,10 +614,10 @@ def _wait_for_completion(client, job_id):
         
         if status == 'completed':
             print_success("🎉 Job completed successfully!")
-            console.print(f"[dim]Get results: ivybloom jobs results {job_id}[/dim]")
+            console.print(f"[dim]Get results: ivybloom jobs results {job_id} --format table[/dim]")
         elif status == 'failed':
             print_error("❌ Job failed!")
-            console.print(f"[dim]Check logs: ivybloom jobs status {job_id} --logs[/dim]")
+            console.print(f"[dim]Check logs: ivybloom jobs status {job_id} --stream --logs[/dim]")
         else:
             print_warning(f"Job ended with status: {status}")
             
