@@ -36,6 +36,8 @@ try:
     from .commands.config import config
     from .commands.workflows import workflows
     from .commands.batch import batch
+    from .commands.reports import reports
+    from .commands.exports import exports
     from .commands.data import data
     from .utils.auth import AuthManager
     from .utils.test_gate import TestGate
@@ -58,6 +60,8 @@ except ImportError:
     from commands.workflows import workflows
     from commands.batch import batch
     from commands.data import data
+    from commands.reports import reports
+    from commands.exports import exports
     from utils.colors import get_console
     from utils.auth import AuthManager
 
@@ -75,15 +79,16 @@ console = get_console()
 @click.option('--no-progress', is_flag=True, help='Disable progress bars and spinners')
 @click.option('--offline', is_flag=True, help='Enable offline mode (use cached data)')
 @click.option('--profile', is_flag=True, help='Enable performance profiling')
+@click.option('--trace-id', help='Set a fixed trace id for all API requests (observability)')
 @click.version_option(version=__version__, prog_name='ivybloom')
 @click.pass_context
-def cli(ctx, config_file, api_url, debug, verbose, output_format, timeout, retries, quiet, no_progress, offline, profile):
+def cli(ctx, config_file, api_url, debug, verbose, output_format, timeout, retries, quiet, no_progress, offline, profile, trace_id):
     """🌿 IvyBloom CLI
 
     - Auth:      ivybloom auth login --browser
     - Tools:     ivybloom tools list | ivybloom tools info <tool>
     - Run:       ivybloom run <tool> key=value [key=value ...]
-    - Jobs:      ivybloom jobs list | ivybloom jobs status <job_id> --follow
+    - Jobs:      ivybloom jobs list | ivybloom jobs status [<job_id>] --follow
     - Workflows: ivybloom workflows run <file.yaml> --dry-run
     - Shell:     ivybloom shell  (interactive mode if available)
 
@@ -115,6 +120,8 @@ def cli(ctx, config_file, api_url, debug, verbose, output_format, timeout, retri
         config.set('offline', True)
     if profile:
         config.set('profile', True)
+    if trace_id:
+        config.set('trace_id', trace_id)
     
     ctx.obj['config'] = config
     ctx.obj['debug'] = debug
@@ -224,6 +231,8 @@ cli.add_command(config)
 cli.add_command(workflows)
 cli.add_command(batch)
 cli.add_command(data)
+cli.add_command(reports)
+cli.add_command(exports)
 
 # Add the run command as a top-level command
 cli.add_command(run)
