@@ -262,6 +262,40 @@ class SplashScreen(ModalScreen[None]):
             yield Static(self._subtitle, classes="muted")
 
 
+def _resolve_selected_index(event, list_view) -> int:
+    """Best-effort to resolve selected index across Textual versions.
+
+    Tries event.index, then list_view.index, then falls back to 0.
+    """
+    try:
+        idx = getattr(event, "index")
+        if isinstance(idx, int):
+            return idx
+    except Exception:
+        pass
+    try:
+        if list_view is not None:
+            idx = getattr(list_view, "index", None)
+            if isinstance(idx, int):
+                return idx
+    except Exception:
+        pass
+    try:
+        # As a last resort, try to locate the event.item within list_view children
+        item = getattr(event, "item", None)
+        if item is not None and list_view is not None:
+            try:
+                children = list_view.children
+                for i, child in enumerate(children):
+                    if child is item:
+                        return i
+            except Exception:
+                pass
+    except Exception:
+        pass
+    return 0
+
+
 class ProjectPicker(ModalScreen[Optional[str]]):
     CSS = """
     ProjectPicker {
@@ -311,7 +345,7 @@ class ProjectPicker(ModalScreen[Optional[str]]):
             self._list.index = 0
 
     def on_list_view_selected(self, event: ListView.Selected) -> None:  # type: ignore[override]
-        index = event.index
+        index = _resolve_selected_index(event, self._list)
         if 0 <= index < len(self._projects):
             pid = str(self._projects[index].get('project_id') or self._projects[index].get('id') or '')
             self.dismiss(pid or None)
@@ -345,7 +379,7 @@ class HistorySelectScreen(ModalScreen[Optional[int]]):
             self._list.index = 0
 
     def on_list_view_selected(self, event: ListView.Selected) -> None:  # type: ignore[override]
-        index = event.index
+        index = _resolve_selected_index(event, self._list)
         if 0 <= index < len(self._entries):
             self.dismiss(index)
         else:
