@@ -454,25 +454,50 @@ class AuthManager:
         # Fallback to API key
         return self.get_api_key() is not None
     
-    def get_auth_headers(self) -> Dict[str, str]:
+    def get_auth_headers(self, *, prefer_jwt: bool = False) -> Dict[str, str]:
         """Get authentication headers for API requests.
         
-        Prefer API key for CLI endpoints. Fall back to JWT, then OAuth access token.
-        This ordering ensures stable auth for both CLI commands and TUI-wrapped calls.
+        Default order (prefer_jwt=False): API key → stored JWT → OAuth access token
+        When prefer_jwt=True: stored JWT → OAuth access token → API key
+        
+        This allows callers to override per-request behavior (e.g., retrying with JWT
+        for backends that require a verifiable user token rather than an API key).
         """
         headers: Dict[str, str] = {}
-        
-        # 1) Prefer API key for stability across environments
+
+        if prefer_jwt:
+            # 1) Stored dedicated JWT
+            jwt_token = self.get_auth_token()
+            if jwt_token:
+                headers["Authorization"] = f"Bearer {jwt_token}"
+                return headers
+            # 2) OAuth access token
+            oauth_tokens = self.get_valid_oauth_tokens()
+            if oauth_tokens and oauth_tokens.get("access_token"):
+                headers["Authorization"] = f"Bearer {oauth_tokens['access_token']}"
+                return headers
+            # 3) Fallback to API key
+            api_key = self.get_api_key()
+            if api_key:
+                # Prefer explicit API key header to avoid JWT parsing on backends
+                headers["X-API-KEY"] = api_key
+                # Maintain Authorization for backward compatibility
+                headers["Authorization"] = f"Bearer {api_key}"
+                return headers
+            return headers
+
+        # Default behavior: prefer API key first for CLI stability
         api_key = self.get_api_key()
         if api_key:
+            # Prefer explicit API key header to avoid JWT parsing on backends
+            headers["X-API-KEY"] = api_key
+            # Maintain Authorization for backward compatibility
             headers["Authorization"] = f"Bearer {api_key}"
             return headers
-        # 2) Next, dedicated stored JWT (if present)
         jwt_token = self.get_auth_token()
         if jwt_token:
             headers["Authorization"] = f"Bearer {jwt_token}"
             return headers
-        # 3) Finally, OAuth access token if present and valid
         oauth_tokens = self.get_valid_oauth_tokens()
         if oauth_tokens and oauth_tokens.get("access_token"):
             headers["Authorization"] = f"Bearer {oauth_tokens['access_token']}"
